==> ejc-metadata-api-3.0.0-20200915.021403-98-sources.jar: com/ejianc/foundation/metadata/vo/MdAttributeVO.java <==
package com.ejianc.foundation.metadata.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

public class MdAttributeVO extends BaseVO {

	private static final long serialVersionUID = 1L;
	public static final String DATA_TYPE_STRING = "string";
	public static final String DATA_TYPE_INTEGER = "integer";
	public static final String DATA_TYPE_LONG = "long";
	public static final String DATA_TYPE_DATETIME = "datetime";
	public static final String DATA_TYPE_DATE = "date";
	public static final String DATA_TYPE_LIST = "list";
	public static final String DATA_TYPE_REFER = "refer";
	public static final String DATA_TYPE_BOOLEAN = "boolean";
	public static final String DATA_TYPE_DECIMAL = "decimal";
	public static final String DATA_TYPE_FLOAT = "float";
	public static final String DATA_TYPE_DOUBLE = "double";

	private String attributeName; // 属性名称

	private String displayName; // 显示名称

	private String dataType; // 数据类型

	private String description;// 描述

	private Integer dataLength;// 数据长度

	private Integer decimalPlace;// 小数位

	private String columnName; // 列名

	private boolean nullFlag; // 是否为空

	private boolean keyFlag; // 是否主键

	private Long entityId; // 实体ID

	private boolean sensitiveFlag;// 是否是敏感字段

	private Integer sequence;// 排序字段

	private boolean refFlag; // 是否参照字段

	private String refMapField;// 参照映射字段

	private Long parentId; // 其关系表 ， 获取属性参照使用
	private String code;// 流程中心使用
	private String name;// 流程中心使用

	private boolean foreignKeyFlag; //是否外键，若是，则该字段为主表主键

	private String dataFormat; //数据格式化，打印使用

	public String getAttributeName() {
		return attributeName;
	}

	public void setAttributeName(String attributeName) {
		this.attributeName = attributeName;
	}

	public String getDisplayName() {
		return displayName;
	}

	public void setDisplayName(String displayName) {
		this.displayName = displayName;
	}

	public String getDataType() {
		return dataType;
	}

	public void setDataType(String dataType) {
		this.dataType = dataType;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public Integer getDataLength() {
		return dataLength;
	}

	public void setDataLength(Integer dataLength) {
		this.dataLength = dataLength;
	}

	public Integer getDecimalPlace() {
		return decimalPlace;
	}

	public void setDecimalPlace(Integer decimalPlace) {
		this.decimalPlace = decimalPlace;
	}

	public String getColumnName() {
		return columnName;
	}

	public void setColumnName(String columnName) {
		this.columnName = columnName;
	}

	public boolean getNullFlag() {
		return nullFlag;
	}

	public void setNullFlag(boolean nullFlag) {
		this.nullFlag = nullFlag;
	}

	public boolean getKeyFlag() {
		return keyFlag;
	}

	public void setKeyFlag(boolean keyFlag) {
		this.keyFlag = keyFlag;
	}

	public Long getEntityId() {
		return entityId;
	}

	public void setEntityId(Long entityId) {
		this.entityId = entityId;
	}

	public boolean getSensitiveFlag() {
		return sensitiveFlag;
	}

	public void setSensitiveFlag(boolean sensitiveFlag) {
		this.sensitiveFlag = sensitiveFlag;
	}

	public Integer getSequence() {
		return sequence;
	}

	public void setSequence(Integer sequence) {
		this.sequence = sequence;
	}

	public boolean isRefFlag() {
		return refFlag;
	}

	public void setRefFlag(boolean refFlag) {
		this.refFlag = refFlag;
	}

	public String getRefMapField() {
		return refMapField;
	}

	public void setRefMapField(String refMapField) {
		this.refMapField = refMapField;
	}

	public Long getParentId() {
		return parentId;
	}

	public void setParentId(Long parentId) {
		this.parentId = parentId;
	}

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = this.getAttributeName();
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = this.getDisplayName()+"("+this.getAttributeName()+")";
	}

	public boolean isForeignKeyFlag() {
		return foreignKeyFlag;
	}

	public void setForeignKeyFlag(boolean foreignKeyFlag) {
		this.foreignKeyFlag = foreignKeyFlag;
	}

	public String getDataFormat() {
		return dataFormat;
	}

	public void setDataFormat(String dataFormat) {
		this.dataFormat = dataFormat;
	}
}

==> ejc-metadata-api-3.0.0-20201026.124547-108-sources.jar: com/ejianc/foundation/metadata/vo/MdAttributeVO.java <==
package com.ejianc.foundation.metadata.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

public class MdAttributeVO extends BaseVO {

	private static final long serialVersionUID = 1L;
	public static final String DATA_TYPE_STRING = "string";
	public static final String DATA_TYPE_INTEGER = "integer";
	public static final String DATA_TYPE_LONG = "long";
	public static final String DATA_TYPE_DATETIME = "datetime";
	public static final String DATA_TYPE_DATE = "date";
	public static final String DATA_TYPE_LIST = "list";
	public static final String DATA_TYPE_REFER = "refer";
	public static final String DATA_TYPE_BOOLEAN = "boolean";
	public static final String DATA_TYPE_DECIMAL = "decimal";
	public static final String DATA_TYPE_FLOAT = "float";
	public static final String DATA_TYPE_DOUBLE = "double";

	private String attributeName; // 属性名称

	private String displayName; // 显示名称

	private String dataType; // 数据类型

	private String description;// 描述

	private Integer dataLength;// 数据长度

	private Integer decimalPlace;// 小数位

	private String columnName; // 列名

	private boolean nullFlag; // 是否为空

	private boolean keyFlag; // 是否主键

	private Long entityId; // 实体ID

	private boolean sensitiveFlag;// 是否是敏感字段

	private Integer sequence;// 排序字段

	private boolean refFlag; // 是否参照字段

	private String refMapField;// 参照映射字段

	private Long parentId; // 其关系表 ， 获取属性参照使用
	private String code;// 流程中心使用
	private String name;// 流程中心使用
	private String mainAttributeField;// 当该实体为子实体时，该字段表示该子实体在主实体中的属性

	private boolean foreignKeyFlag; //是否外键，若是，则该字段为主表主键

	private String dataFormat; //数据格式化，打印使用

	public String getAttributeName() {
		return attributeName;
	}

	public void setAttributeName(String attributeName) {
		this.attributeName = attributeName;
	}

	public String getDisplayName() {
		return displayName;
	}

	public void setDisplayName(String displayName) {
		this.displayName = displayName;
	}

	public String getDataType() {
		return dataType;
	}

	public void setDataType(String dataType) {
		this.dataType = dataType;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public Integer getDataLength() {
		return dataLength;
	}

	public void setDataLength(Integer dataLength) {
		this.dataLength = dataLength;
	}

	public Integer getDecimalPlace() {
		return decimalPlace;
	}

	public void setDecimalPlace(Integer decimalPlace) {
		this.decimalPlace = decimalPlace;
	}

	public String getColumnName() {
		return columnName;
	}

	public void setColumnName(String columnName) {
		this.columnName = columnName;
	}

	public boolean getNullFlag() {
		return nullFlag;
	}

	public void setNullFlag(boolean nullFlag) {
		this.nullFlag = nullFlag;
	}

	public boolean getKeyFlag() {
		return keyFlag;
	}

	public void setKeyFlag(boolean keyFlag) {
		this.keyFlag = keyFlag;
	}

	public Long getEntityId() {
		return entityId;
	}

	public void setEntityId(Long entityId) {
		this.entityId = entityId;
	}

	public boolean getSensitiveFlag() {
		return sensitiveFlag;
	}

	public void setSensitiveFlag(boolean sensitiveFlag) {
		this.sensitiveFlag = sensitiveFlag;
	}

	public Integer getSequence() {
		return sequence;
	}

	public void setSequence(Integer sequence) {
		this.sequence = sequence;
	}

	public boolean isRefFlag() {
		return refFlag;
	}

	public void setRefFlag(boolean refFlag) {
		this.refFlag = refFlag;
	}

	public String getRefMapField() {
		return refMapField;
	}

	public void setRefMapField(String refMapField) {
		this.refMapField = refMapField;
	}

	public Long getParentId() {
		return parentId;
	}

	public void setParentId(Long parentId) {
		this.parentId = parentId;
	}

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = this.getAttributeName();
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = this.getDisplayName()+"("+this.getAttributeName()+")";
	}

	public boolean isForeignKeyFlag() {
		return foreignKeyFlag;
	}

	public void setForeignKeyFlag(boolean foreignKeyFlag) {
		this.foreignKeyFlag = foreignKeyFlag;
	}

	public String getDataFormat() {
		return dataFormat;
	}

	public void setDataFormat(String dataFormat) {
		this.dataFormat = dataFormat;
	}

	public String getMainAttributeField() {
		return mainAttributeField;
	}

	public void setMainAttributeField(String mainAttributeField) {
		this.mainAttributeField = mainAttributeField;
	}
	
}
